aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/color_dlg.h
diff options
context:
space:
mode:
authorUlf Lamping <ulf.lamping@web.de>2006-10-02 23:11:55 +0000
committerUlf Lamping <ulf.lamping@web.de>2006-10-02 23:11:55 +0000
commit6cde05da1bfb6e43365a3d2fc6f7ca03d49be65e (patch)
tree2baaa89881602c2b1a089211230bed32d0a8bddc /gtk/color_dlg.h
parent59d206d18e8b059239b4e52cdc30a8adb144b547 (diff)
missing mark -> select changes
svn path=/trunk/; revision=19400
Diffstat (limited to 'gtk/color_dlg.h')
-rw-r--r--gtk/color_dlg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/color_dlg.h b/gtk/color_dlg.h
index c0e7388cab..caaf158806 100644
--- a/gtk/color_dlg.h
+++ b/gtk/color_dlg.h
@@ -43,10 +43,10 @@ void color_display_cb(GtkWidget *widget, gpointer data);
*/
void color_display_with_filter(char *filter);
/** Count the number of color filters.
*
* @return the number of color filters
*/
-int color_marked_count(void);
+int color_selected_count(void);
#endif /* color_dlg.h */
@@ -43,10 +43,10 @@ void color_display_cb(GtkWidget *widget, gpointer data);
*/
void color_display_with_filter(char *filter);
-/** Count the number of color filters.
+/** Count the number of selected color filters.
*
@@ -43,10 +43,10 @@ void color_display_cb(GtkWidget *widget, gpointer data);
*
- * @return the number of color filters
+ * @return the number of selected color filters
*/